leiningen.sub-bump


bump-versions-in-fileclj

(bump-versions-in-file file-path new-version artifact-names)

Step 2: rewrites file-path, replacing the version string of any dependency whose full name (including group) is in artifact-names.

Step 2: rewrites file-path, replacing the version string of any dependency
whose full name (including group) is in artifact-names.
sourceraw docstring

collect-sub-project-namesclj

(collect-sub-project-names base-dir subs)

Step 1: walks every sub-project directory and returns a set of the full artifact names found in their project.clj files.

Step 1: walks every sub-project directory and returns a set of the full
artifact names found in their project.clj files.
sourceraw docstring

escape-regexclj

(escape-regex s)
source

read-project-nameclj

(read-project-name file-path)

Reads a project.clj file and returns the full artifact name as declared in defproject, e.g. "org.clojars.jj/boa-async-query".

Reads a project.clj file and returns the full artifact name as declared
in defproject, e.g. "org.clojars.jj/boa-async-query".
sourceraw docstring

sub-bumpclj

(sub-bump project & _args)
source

cljdoc builds & hosts documentation for Clojure/Script libraries