(bump-versions-in-file file-path new-version artifact-names)Step 2: rewrites file-path, replacing the version string of any dependency whose full name (including group) is in artifact-names.
Step 2: rewrites file-path, replacing the version string of any dependency whose full name (including group) is in artifact-names.
(collect-sub-project-names base-dir subs)Step 1: walks every sub-project directory and returns a set of the full artifact names found in their project.clj files.
Step 1: walks every sub-project directory and returns a set of the full artifact names found in their project.clj files.
(read-project-name file-path)Reads a project.clj file and returns the full artifact name as declared in defproject, e.g. "org.clojars.jj/boa-async-query".
Reads a project.clj file and returns the full artifact name as declared in defproject, e.g. "org.clojars.jj/boa-async-query".
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |